@@ -39,7 +39,7 @@
   (set-statusbar-message (get-stock-no-string)))
 
 (define (get-stock-no-string)
-  (string-append (_"Stock left:") " "
+  (string-append (G_"Stock left:") " "
 		 (number->string (length (get-cards 0)))))
 
 (define (button-pressed slot-id card-list)
@@ -124,7 +124,7 @@
 
 (define (dealable?)
   (and (not (empty-slot? 0))
-       (list 0 (_"Deal another round"))))
+       (list 0 (G_"Deal another round"))))
 
 (define (removable?)
   (and (not (empty-slot? 1))
@@ -136,33 +136,33 @@
 	  (get-value (get-top-card 3))
 	  (get-value (get-top-card 4)))
        (list 0 (cond ((= (get-value (get-top-card 1)) 1)
-                      (_"Remove the aces"))
+                      (G_"Remove the aces"))
                      ((= (get-value (get-top-card 1)) 2)
-                      (_"Remove the twos"))
+                      (G_"Remove the twos"))
                      ((= (get-value (get-top-card 1)) 3)
-                      (_"Remove the threes"))
+                      (G_"Remove the threes"))
                      ((= (get-value (get-top-card 1)) 4)
-                      (_"Remove the fours"))
+                      (G_"Remove the fours"))
                      ((= (get-value (get-top-card 1)) 5)
-                      (_"Remove the fives"))
+                      (G_"Remove the fives"))
                      ((= (get-value (get-top-card 1)) 6)
-                      (_"Remove the sixes"))
+                      (G_"Remove the sixes"))
                      ((= (get-value (get-top-card 1)) 7)
-                      (_"Remove the sevens"))
+                      (G_"Remove the sevens"))
                      ((= (get-value (get-top-card 1)) 8)
-                      (_"Remove the eights"))
+                      (G_"Remove the eights"))
                      ((= (get-value (get-top-card 1)) 9)
-                      (_"Remove the nines"))
+                      (G_"Remove the nines"))
                      ((= (get-value (get-top-card 1)) 10)
-                      (_"Remove the tens"))
+                      (G_"Remove the tens"))
                      ((= (get-value (get-top-card 1)) 11)
-                      (_"Remove the jacks"))
+                      (G_"Remove the jacks"))
                      ((= (get-value (get-top-card 1)) 12)
-                      (_"Remove the queens"))
+                      (G_"Remove the queens"))
                      ((= (get-value (get-top-card 1)) 13)
-                      (_"Remove the kings"))
+                      (G_"Remove the kings"))
                      (#t
-                      (_"I'm not sure"))))))
+                      (G_"I'm not sure"))))))
 
 (define (move-leftable? slot1 slot2)
   (cond ((= slot1 4)
@@ -181,7 +181,7 @@
   (or (removable?)
       (move-leftable? 1 2)
       (dealable?)
-      (list 0 (_"Return cards to stock"))))
+      (list 0 (G_"Return cards to stock"))))
 
 (define (get-options) 
   #f)
