@@ -622,13 +622,13 @@
 ; move format: ((board . info) start-slot card card-count end-slot)
 (define (create-help-list board moves)
   (if (null? moves)
-    (list 0 (_"No moves are possible. Undo or start again."))
+    (list 0 (G_"No moves are possible. Undo or start again."))
     (let* ((best-move (car moves))
 	   (from-card (caddr best-move))
 	   (to-slot   (list-ref best-move 4))
 	   (to-stack  (vector-ref board to-slot)))
       (if (eq? (vector-ref (cdar best-move) index-outcome) outcome-lose)
-	(list 0 (_"The game has no solution. Undo or start again."))
+	(list 0 (G_"The game has no solution. Undo or start again."))
 	(hint-move (find-card-slot from-card) (find-card (find-card-slot from-card) from-card)
 	      (cond ((freecell? to-slot) (find-empty-slot freecells))
 		    ((homecell? to-slot)
