@@ -73,25 +73,25 @@
 					(get-base-string))))
 
 (define (get-stock-no-string)
-  (string-append (_"Stock left:") " " 
+  (string-append (G_"Stock left:") " " 
 		 (number->string (length (get-cards 0)))))
 
 (define (get-reserve-no-string)
-  (string-append (_"Reserve left:") " " 
+  (string-append (G_"Reserve left:") " " 
 		 (number->string (length (get-cards 6)))))
 
 (define (get-base-string)
   (cond ((and (> BASE-VAL 1)
 	      (< BASE-VAL 11))
-	 (string-append (_"Base Card: ") (number->string BASE-VAL)))
+	 (string-append (G_"Base Card: ") (number->string BASE-VAL)))
 	((= BASE-VAL 1)
-	 (_"Base Card: Ace"))
+	 (G_"Base Card: Ace"))
 	((= BASE-VAL 11)
-	 (_"Base Card: Jack"))
+	 (G_"Base Card: Jack"))
 	((= BASE-VAL 12)
-	 (_"Base Card: Queen"))
+	 (G_"Base Card: Queen"))
 	((= BASE-VAL 13)
-	 (_"Base Card: King"))
+	 (G_"Base Card: King"))
 	(#t "")))
 
 (define (button-pressed slot-id card-list)
@@ -216,7 +216,7 @@
 
 (define (dealable?)
   (and (not (empty-slot? 0))
-       (list 0 (_"Deal another card"))))
+       (list 0 (G_"Deal another card"))))
 
 (define (check-a-foundation card foundation-slot)
   (cond ((> foundation-slot 5)
