@@ -155,9 +155,9 @@
       (if (= slot-id to-slot)
 	  (check-a-slot slot-id number-to-move (+ 1 to-slot))
 	  (cond ((empty-slot? slot-id)
-		 (list 2 (_"something") (_"an empty slot")))
+		 (list 2 (G_"something") (G_"an empty slot")))
 		((empty-slot? to-slot)
-		 (list 2 (_"something") (_"an empty slot")))
+		 (list 2 (G_"something") (G_"an empty slot")))
 		((= 4 (length (get-cards to-slot)))
 		 (check-a-slot slot-id number-to-move (+ 1 to-slot)))
 		((= (get-value (get-top-card to-slot))
