@@ -19,7 +19,6 @@
  */
 
 #include "config.h"
-
 #include "ar-application.h"
 
 #include <stdlib.h>
@@ -38,30 +37,18 @@
 #include "game.h"
 #include "util.h"
 
-struct _ArApplicationClass {
-  GtkApplicationClass parent_class;
-};
-
 struct _ArApplication {
   GtkApplication parent_instance;
 
-  /*< private >*/
-  ArApplicationPrivate *priv;
-};
-
-struct _ArApplicationPrivate
-{
   AisleriotWindow *window;
   char *variation;
   gint seed; /* unused */
   gboolean freecell; /* unused */
 };
 
-#if !GTK_CHECK_VERSION (3, 6, 0)
-#define gtk_application_get_active_window(w) NULL
-#endif
 
-G_DEFINE_TYPE (ArApplication, ar_application, GTK_TYPE_APPLICATION)
+G_DEFINE_TYPE (ArApplication, ar_application, GTK_TYPE_APPLICATION);
+
 
 static void
 action_new_game (GSimpleAction *action,
@@ -164,7 +151,7 @@ action_quit (GSimpleAction *simple,
 {
   ArApplication *self = AR_APPLICATION (user_data);
 
-  gtk_widget_destroy (GTK_WIDGET (self->priv->window));
+  gtk_widget_destroy (GTK_WIDGET (self->window));
 }
 
 static void
@@ -172,7 +159,7 @@ ar_application_activate (GApplication *application)
 {
   ArApplication *self = AR_APPLICATION (application);
 
-  gtk_window_present (GTK_WINDOW (self->priv->window));
+  gtk_window_present (GTK_WINDOW (self->window));
 }
 
 static GActionEntry app_entries[] = {
@@ -189,42 +176,17 @@ static void
 ar_application_startup (GApplication *application)
 {
   ArApplication *self = AR_APPLICATION (application);
-  ArApplicationPrivate *priv = self->priv;
-  GMenu *menu;
-  GMenu *section;
 
   G_APPLICATION_CLASS (ar_application_parent_class)->startup (application);
 
   ar_sound_enable (FALSE);
   ar_stock_init ();
 
-  gtk_window_set_default_icon_name (priv->freecell ? "gnome-freecell" : "gnome-aisleriot");
+  gtk_window_set_default_icon_name (self->freecell ? "gnome-freecell" : "gnome-aisleriot");
 
-  g_action_map_add_action_entries (G_ACTION_MAP (self),
+  g_action_map_add_action_entries (G_ACTION_MAP (application),
                                    app_entries, G_N_ELEMENTS (app_entries),
-                                   self);
-
-  menu = g_menu_new ();
-
-  section = g_menu_new ();
-  g_menu_append (section, _("New Game"), "app.new-game");
-  g_menu_append (section, _("Change Game"), "app.change-game");
-  g_menu_append_section (menu, NULL, G_MENU_MODEL (section));
-
-  section = g_menu_new ();
-  g_menu_append (section, _("Statistics"), "app.statistics");
-  g_menu_append (section, _("Fullscreen"), "app.fullscreen");
-  g_menu_append_section (menu, NULL, G_MENU_MODEL (section));
-
-  section = g_menu_new ();
-  g_menu_append (section, _("Help"), "app.help");
-  g_menu_append (section, _("About"), "app.about");
-  g_menu_append (section, _("Quit"), "app.quit");
-
-  g_menu_append_section (menu, NULL, G_MENU_MODEL (section));
-
-  gtk_application_set_app_menu (GTK_APPLICATION (application),
-                                G_MENU_MODEL (menu));
+                                   application);
 
   gtk_application_add_accelerator (GTK_APPLICATION (application),
                                    "F11", "app.fullscreen", NULL);
@@ -233,12 +195,12 @@ ar_application_startup (GApplication *application)
 
   gtk_window_set_default_icon_name ("gnome-aisleriot");
 
-  priv->window = AISLERIOT_WINDOW (aisleriot_window_new (GTK_APPLICATION (application)));
+  self->window = AISLERIOT_WINDOW (aisleriot_window_new (GTK_APPLICATION (application)));
 
-  if (priv->freecell) {
-    aisleriot_window_set_game_module (priv->window, FREECELL_VARIATION, NULL);
+  if (self->freecell) {
+    aisleriot_window_set_game_module (self->window, FREECELL_VARIATION, NULL);
   } else {
-    aisleriot_window_set_game_module (priv->window, priv->variation, NULL);
+    aisleriot_window_set_game_module (self->window, self->variation, NULL);
   }
 }
 
@@ -247,18 +209,15 @@ ar_application_dispose (GObject *object)
 {
   ArApplication *self = AR_APPLICATION (object);
 
-  G_OBJECT_CLASS (ar_application_parent_class)->dispose (object);
+  g_clear_pointer (&self->variation, g_free);
 
-  g_free (self->priv->variation);
-  self->priv->variation = NULL;
+  G_OBJECT_CLASS (ar_application_parent_class)->dispose (object);
 }
 
 static void
 ar_application_init (ArApplication *self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-                                            AR_TYPE_APPLICATION,
-                                            ArApplicationPrivate);
+  /* pass */
 }
 
 static void
@@ -271,22 +230,22 @@ ar_application_class_init (ArApplicationClass *class)
 
   application_class->activate = ar_application_activate;
   application_class->startup = ar_application_startup;
-
-  g_type_class_add_private (class, sizeof (ArApplicationPrivate));
 }
 
 GtkApplication *
 ar_application_new (const char *variation,
-                    gboolean freecell)
+                    gboolean    freecell)
 {
   ArApplication *app;
 
   app = g_object_new (AR_TYPE_APPLICATION,
-                      "application-id", "org.gnome.Aisleriot",
+                      "application-id", "org.gnome.aisleriot",
                       "flags", G_APPLICATION_NON_UNIQUE,
                       NULL);
-  app->priv->variation = g_strdup (variation);
-  app->priv->freecell = freecell != FALSE;
+
+  /* FIXME: This should be done as properties */
+  app->variation = g_strdup (variation);
+  app->freecell = freecell != FALSE;
 
   return GTK_APPLICATION (app);
 }
