@@ -44,15 +44,10 @@
 static GtkStyleProvider *
 ar_style_provider_new (void)
 {
-#ifdef HAVE_CLUTTER
-#define NAME "ArClutterEmbed"
-#else
-#define NAME "AisleriotBoard"
-#endif
   static const char css[] =
-    "" NAME "{\n"
+    " AisleriotBoard, aisleriot-board {\n"
       "background-color: " DEFAULT_BACKGROUND_COLOR_STRING ";\n"
-      "-" NAME "-selection-color: " DEFAULT_SELECTION_COLOR_STRING ";\n"
+      "-AisleriotBoard-selection-color: " DEFAULT_SELECTION_COLOR_STRING ";\n"
       "background-image: url('resource:///org/gnome/aisleriot/art/baize.png');\n"
       "background-repeat: repeat;\n"
   "}\n";
@@ -74,7 +69,7 @@ sync_settings (GtkSettings *settings,
                GParamSpec *pspec,
                ArStyle *style)
 {
-  ArStylePrivate *style_priv = style->priv;
+  ArStylePrivate *style_priv = ar_style_get_instance_private_exported (style);
   GObject *style_object = G_OBJECT (style);
   const char *pspec_name;
 
@@ -160,7 +155,7 @@ direction_changed_cb (GtkWidget *widget,
                       GtkTextDirection previous_direction,
                       ArStyle *style)
 {
-  ArStylePrivate *style_priv = style->priv;
+  ArStylePrivate *style_priv = ar_style_get_instance_private_exported (style);
   GObject *style_object = G_OBJECT (style);
   GtkTextDirection direction;
   gboolean rtl;
@@ -233,7 +228,7 @@ static void
 style_updated_cb (GtkWidget *widget,
                   ArStyle *style)
 {
-  ArStylePrivate *style_priv = style->priv;
+  ArStylePrivate *style_priv = ar_style_get_instance_private_exported (style);
   GObject *style_object = G_OBJECT (style);
   GdkRGBA *selection_color;
   int focus_line_width, focus_padding;
