@@ -115,6 +115,10 @@ gboolean _ar_card_theme_class_foreach_env (ArCardThemeClass *klass,
                                               const char *env,
                                               ArCardThemeForeachFunc callback,
                                               gpointer data);
+gboolean _ar_card_theme_class_foreach_user_dir (ArCardThemeClass *klass,
+						const char *name,
+						ArCardThemeForeachFunc callback,
+						gpointer data);
 
 void _ar_card_theme_emit_changed (ArCardTheme *theme);
 
@@ -187,9 +191,9 @@ ArCardTheme* ar_card_theme_svg_new (void);
 
 #endif /* HAVE_RSVG */
 
-#if 1 //def HAVE_QTSVG
+#ifdef HAVE_QTSVG
 
-/* ArCardThemeQSvg (abstract) */
+/* ArCardThemeQSvg */
 
 #define AR_TYPE_CARD_THEME_QSVG            (ar_card_theme_qsvg_get_type ())
 #define AR_CARD_THEME_QSVG(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), AR_TYPE_CARD_THEME_QSVG, ArCardThemeQSvg))
@@ -203,6 +207,8 @@ typedef struct _ArCardThemeQSvg      ArCardThemeQSvg;
 
 GType ar_card_theme_qsvg_get_type (void);
 
+ArCardTheme* ar_card_theme_qsvg_new (void);
+
 /* ArCardThemeNative */
 
 #define AR_TYPE_CARD_THEME_NATIVE            (ar_card_theme_native_get_type ())
