@@ -179,6 +179,14 @@ ar_card_theme_class_real_paint_card (ArCardTheme *theme,
   g_object_unref (pixbuf);
 }
 
+static void
+card_pixbuf_destroy (guchar   *pixels,
+                     gpointer  data)
+{
+  g_free (pixels);
+}
+
+
 static GdkPixbuf *
 ar_card_theme_class_real_get_card_pixbuf (ArCardTheme *card_theme,
                                           int card_id)
@@ -213,7 +221,7 @@ ar_card_theme_class_real_get_card_pixbuf (ArCardTheme *card_theme,
                                    8,
                                    card_size.width, card_size.height,
                                    rowstride,
-                                   (GdkPixbufDestroyNotify) g_free, data);
+                                   card_pixbuf_destroy, NULL);
 }
 
 static void
@@ -324,6 +332,23 @@ _ar_card_theme_class_foreach_env (ArCardThemeClass *klass,
   return retval;
 }
 
+gboolean
+_ar_card_theme_class_foreach_user_dir (ArCardThemeClass *klass,
+				       const char *name,
+				       ArCardThemeForeachFunc callback,
+				       gpointer data)
+{
+  const char *udd = g_get_user_data_dir();
+  if (!udd)
+    return TRUE;
+
+  char *path = g_build_filename(udd, "aisleriot", name, NULL);
+  gboolean rv = callback(klass, path, data);
+  g_free(path);
+
+  return rv;
+}
+
 /* public API */
 
 /**
