@@ -33,7 +33,7 @@
 
 #include "ar-conf.h"
 
-#define AR_CONF_GET_PRIVATE(that)(G_TYPE_INSTANCE_GET_PRIVATE ((that), AR_TYPE_CONF, ArConfPrivate))
+#define AR_CONF_GET_PRIVATE(obj) (ar_conf_get_instance_private(obj))
 
 struct ArConfPrivate {
   char *game_name;
@@ -66,7 +66,8 @@ static guint signals[LAST_SIGNAL];
 
 static ArConf *instance;
 
-G_DEFINE_TYPE (ArConf, ar_conf, G_TYPE_OBJECT);
+G_DEFINE_TYPE_EXTENDED (ArConf, ar_conf, G_TYPE_OBJECT, 0,
+                        G_ADD_PRIVATE (ArConf));
 
 /* helper functions */
 
@@ -134,23 +135,28 @@ free_window_state (WindowState *state)
   g_slice_free (WindowState, state);
 }
 
-static gboolean
-window_configure_event_cb (GtkWidget *widget,
-                           GdkEventConfigure *event,
-                           WindowState *state)
+static void
+window_size_allocate_cb (GtkWidget *widget,
+                         GtkAllocation *allocation,
+                         WindowState *state)
 {
+  int width, height;
+
+  gtk_window_get_size (GTK_WINDOW (widget), &width, &height);
+
+
   ar_debug_print (AR_DEBUG_WINDOW_STATE,
-                      "[window %p] configure event current %dx%d new %dx%d [state: is-maximised:%s is-fullscreen:%s]\n",
+                  "[window %p] size allocate %dx%d new %dx%d [state: is-maximised:%s is-fullscreen:%s]\n",
                       state->window,
                       state->width, state->height,
-                      event->width, event->height,
+                      width, height,
                       state->is_maximised ? "t" : "f",
                       state->is_fullscreen ? "t" : "f");
 
   if (!state->is_maximised && !state->is_fullscreen &&
-      (state->width != event->width || state->height != event->height)) {
-    state->width = event->width;
-    state->height = event->height;
+      (state->width != width || state->height != height)) {
+    state->width = width;
+    state->height = height;
 
   ar_debug_print (AR_DEBUG_WINDOW_STATE,
                       "[window %p] scheduling save of new window size\n",
@@ -162,8 +168,6 @@ window_configure_event_cb (GtkWidget *widget,
                                                  state);
     }
   }
-
-  return FALSE;
 }
 
 static gboolean
@@ -203,7 +207,6 @@ ar_conf_get_accel_map_path (ArConf *conf,
   ArConfPrivate *priv = conf->priv;
   char *game_name, *conf_dir;
   char *conf_file = NULL;
-  const char *override;
 
   game_name = g_ascii_strdown (priv->game_name, -1);
 
@@ -523,8 +526,6 @@ ar_conf_class_init (ArConfClass *klass)
                           NULL,
                           G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB |
                           G_PARAM_CONSTRUCT_ONLY));
-
-  g_type_class_add_private (gobject_class, sizeof (ArConfPrivate));
 }
 
 /* public API */
@@ -1284,8 +1285,8 @@ ar_conf_add_window (GtkWindow *window,
   g_object_set_data_full (G_OBJECT (window), "ArConf::WindowState",
                           state, (GDestroyNotify) free_window_state);
 
-  g_signal_connect (window, "configure-event",
-                    G_CALLBACK (window_configure_event_cb), state);
+  g_signal_connect_after (window, "size-allocate",
+                          G_CALLBACK (window_size_allocate_cb), state);
   g_signal_connect (window, "window-state-event",
                     G_CALLBACK (window_state_event_cb), state);
 
