@@ -113,9 +113,9 @@ ar_help_display_full (GtkWidget *window,
     
 #elif defined(WITH_HELP_METHOD_LIBRARY)
   if (section != NULL) {
-    help_uri = g_strdup_printf ("http://library.gnome.org/users/%s/stable/%s.html", doc_module, section);
+    help_uri = g_strdup_printf ("https://help.gnome.org/users/%s/stable/%s.html", doc_module, section);
   } else {
-    help_uri = g_strdup_printf ("http://library.gnome.org/users/%s/stable/", doc_module);
+    help_uri = g_strdup_printf ("https://help.gnome.org/users/%s/stable/", doc_module);
   }
 #endif
 
